aboutsummaryrefslogtreecommitdiffstats
path: root/services/hv-ves-client/protobuf/src/main/proto/VesEvent.proto
diff options
context:
space:
mode:
Diffstat (limited to 'services/hv-ves-client/protobuf/src/main/proto/VesEvent.proto')
-rw-r--r--services/hv-ves-client/protobuf/src/main/proto/VesEvent.proto5
1 files changed, 3 insertions, 2 deletions
diff --git a/services/hv-ves-client/protobuf/src/main/proto/VesEvent.proto b/services/hv-ves-client/protobuf/src/main/proto/VesEvent.proto
index 2db6b64e..31691fc1 100644
--- a/services/hv-ves-client/protobuf/src/main/proto/VesEvent.proto
+++ b/services/hv-ves-client/protobuf/src/main/proto/VesEvent.proto
@@ -2,7 +2,7 @@
* ============LICENSE_START=======================================================
* dcaegen2-collectors-veshv
* ================================================================================
- * Copyright (C) 2018 NOKIA
+ * Copyright (C) 2018-2021 NOKIA
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@ message CommonEventHeader
string version = 1; // required, "version of the gpb common event header", current value "1.0"
string domain = 2; // required, "the eventing domain associated with the event", allowed values:
// fault, heartbeat, measurement, mobileFlow, other, pnfRegistration, sipSignaling,
// stateChange, syslog, thresholdCrossingAlert, voiceQuality, perf3gpp
uint32 sequence = 3; // required, "ordering of events communicated by an event source instance or 0 if not needed"
@@ -69,6 +69,7 @@ message CommonEventHeader
string sourceName = 16; // required, "name of the entity experiencing the event issued use A&AI entry"
string timeZoneOffset = 17; // "Offset to GMT to indicate local time zone for the device"
string vesEventListenerVersion = 18; // required, "Version of the VesEvent Listener", current value "7.2"
+ string stndDefinedNamespace = 19; // optional, routing base when domain is "stndDefined"
reserved "InternalHeaderFields"; // "enrichment fields for internal VES Event Listener service use only, not supplied by event sources"
reserved 100;
@@ -38,7 +38,7 @@ message CommonEventHeader
string domain = 2; // required, "the eventing domain associated with the event", allowed values:
// fault, heartbeat, measurement, mobileFlow, other, pnfRegistration, sipSignaling,
- // stateChange, syslog, thresholdCrossingAlert, voiceQuality, perf3gpp
+ // stateChange, stndDefined, syslog, thresholdCrossingAlert, voiceQuality, perf3gpp
uint32 sequence = 3; // required, "ordering of events communicated by an event source instance or 0 if not needed"